@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: ipsec_kversion.h,v 1.15.2.21 2008-02-17 20:35:35 paul Exp $
+ * RCSID $Id: ipsec_kversion.h,v 1.15.2.24 2008-04-11 00:30:07 paul Exp $
  */
 #define	_OPENSWAN_KVERSIONS_H	/* seen it, no need to see it again */
 
@@ -186,6 +186,14 @@
 #  define skb_mac_header(skb)  ((skb)->mac.raw)
 #  define skb_set_mac_header(skb,off)  ((skb)->mac.raw = (skb)->data + (off))
 #endif
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,24)
+#define LINUX_PROCNET init_net.proc_net
+#else
+#define LINUX_PROCNET proc_net
+#endif
+
+
 /* turn a pointer into an offset for above macros */
 #define ipsec_skb_offset(skb, ptr) (((unsigned char *)(ptr)) - (skb)->data)
 
@@ -213,8 +221,15 @@
 #define device net_device
 #endif
 #endif
-# define ipsec_dev_get dev_get_by_name
-# define __ipsec_dev_get __dev_get_by_name
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,24)
+#define __ipsec_dev_get(x) __dev_get_by_name(&init_net, x)
+#define ipsec_dev_get(x) dev_get_by_name(&init_net, x)
+#else
+#define ipsec_dev_get(x) __dev_get_by_name(x)
+#define __ipsec_dev_get(x) __dev_get_by_name(x)
+#endif
+
 # define ipsec_dev_put(x) dev_put(x)
 # define __ipsec_dev_put(x) __dev_put(x)
 # define ipsec_dev_hold(x) dev_hold(x)
@@ -291,139 +306,3 @@
 
 #endif /* _OPENSWAN_KVERSIONS_H */
 
-/*
- * $Log: ipsec_kversion.h,v $
- * Revision 1.15.2.21  2008-02-17 20:35:35  paul
- * enable HAVE_NEW_SKB_LINEARIZE for Suse Linux SLES10 SP1
- *
- * Revision 1.15.2.20  2007-11-16 06:16:10  paul
- * Fix brackets on SKB_RESET_NFCT case
- *
- * Revision 1.15.2.19  2007-11-16 06:01:27  paul
- * On 2.6.23+, sk->nfct is part of skbut only when CONFIG_NF_CONNTRACK or
- * CONFIG_NF_CONNTRACK_MODUE is set, where previously this was handled with
- * CONFIG_NETFILTER.
- *
- * Revision 1.15.2.18  2007-11-07 14:17:56  paul
- * Xen modifies skb structures, so xen kernels < 2.6.18 need to have
- * HAVE_NEW_SKB_LINEARIZE defined.
- *
- * Revision 1.15.2.17  2007-10-31 19:57:40  paul
- * type of sock.sk_stamp changed from timeval to ktime [dhr]
- *
- * Revision 1.15.2.16  2007-10-30 22:17:02  paul
- * Move the define for ktime_to_timeval() from "not 2.6.22" to "< 2.6.16",
- * where it belongs.
- *
- * Revision 1.15.2.15  2007-10-30 21:44:00  paul
- * added a backport definition for define skb_end_pointer [dhr]
- *
- * Revision 1.15.2.14  2007-10-28 00:26:03  paul
- * Start of fix for 2.6.22+ kernels and skb_tail_pointer()
- *
- * Revision 1.15.2.13  2007/09/05 02:28:27  paul
- * Patch by David McCullough for 2.6.22 compatibility (HAVE_KERNEL_TSTAMP,
- * HAVE_DEV_NEXT and other header surgery)
- *
- * Revision 1.15.2.12  2007/08/10 01:40:49  paul
- * Fix for sock_unregister for 2.6.19 by Sergeil
- *
- * Revision 1.15.2.11  2007/02/20 03:53:16  paul
- * Added comment, made layout consistent with other checks.
- *
- * Revision 1.15.2.10  2007/02/16 19:08:12  paul
- * Fix for compiling on 2.6.20 (nfmark is now called mark in sk_buff)
- *
- * Revision 1.15.2.9  2006/07/29 05:00:40  paul
- * Added HAVE_NEW_SKB_LINEARIZE for 2.6.18+ kernels where skb_linearize
- * only takes 1 argument.
- *
- * Revision 1.15.2.8  2006/05/01 14:31:52  mcr
- * FREESWAN->OPENSWAN in #ifdef.
- *
- * Revision 1.15.2.7  2006/01/11 02:02:59  mcr
- * updated patches and DEFAULT_TTL code to work
- *
- * Revision 1.15.2.6  2006/01/03 19:25:02  ken
- * Remove duplicated #ifdef for TTL fix - bad patch
- *
- * Revision 1.15.2.5  2006/01/03 18:06:33  ken
- * Fix for missing sysctl default ttl
- *
- * Revision 1.15.2.4  2005/11/27 21:40:14  paul
- * Pull down TTL fixes from head. this fixes "Unknown symbol sysctl_ip_default_ttl"
- * in for klips as module.
- *
- * Revision 1.15.2.3  2005/11/22 04:11:52  ken
- * Backport fixes for 2.6.14 kernels from HEAD
- *
- * Revision 1.15.2.2  2005/09/01 01:57:19  paul
- * michael's fixes for 2.6.13 from head
- *
- * Revision 1.15.2.1  2005/08/27 23:13:48  paul
- * Fix for:
- * 7 weeks ago:  	[NET]: Remove unused security member in sk_buff
- * changeset 4280: 	328ea53f5fee
- * parent 4279:	beb0afb0e3f8
- * author: 	Thomas Graf <tgraf@suug.ch>
- * date: 	Tue Jul 5 21:12:44 2005
- * files: 	include/linux/skbuff.h include/linux/tc_ematch/tc_em_meta.h net/core/skbuff.c net/ipv4/ip_output.c net/ipv6/ip6_output.c net/sched/em_meta.c
- *
- * This should fix compilation on 2.6.13(rc) kernels
- *
- * Revision 1.15  2005/07/19 20:02:15  mcr
- * 	sk_alloc() interface change.
- *
- * Revision 1.14  2005/07/08 16:20:05  mcr
- * 	fix for 2.6.12 disapperance of sk_zapped field -> sock_flags.
- *
- * Revision 1.13  2005/05/20 03:19:18  mcr
- * 	modifications for use on 2.4.30 kernel, with backported
- * 	printk_ratelimit(). all warnings removed.
- *
- * Revision 1.12  2005/04/13 22:46:21  mcr
- * 	note that KLIPS does not work on Linux 2.0.
- *
- * Revision 1.11  2004/09/13 02:22:26  mcr
- * 	#define inet_protocol if necessary.
- *
- * Revision 1.10  2004/08/03 18:17:15  mcr
- * 	in 2.6, use "net_device" instead of #define device->net_device.
- * 	this probably breaks 2.0 compiles.
- *
- * Revision 1.9  2004/04/05 19:55:05  mcr
- * Moved from linux/include/freeswan/ipsec_kversion.h,v
- *
- * Revision 1.8  2003/12/13 19:10:16  mcr
- * 	refactored rcv and xmit code - same as FS 2.05.
- *
- * Revision 1.7  2003/07/31 22:48:08  mcr
- * 	derive NET25-ness from presence of NETLINK_XFRM macro.
- *
- * Revision 1.6  2003/06/24 20:22:32  mcr
- * 	added new global: ipsecdevices[] so that we can keep track of
- * 	the ipsecX devices. They will be referenced with dev_hold(),
- * 	so 2.2 may need this as well.
- *
- * Revision 1.5  2003/04/03 17:38:09  rgb
- * Centralised ipsec_kfree_skb and ipsec_dev_{get,put}.
- *
- * Revision 1.4  2002/04/24 07:36:46  mcr
- * Moved from ./klips/net/ipsec/ipsec_kversion.h,v
- *
- * Revision 1.3  2002/04/12 03:21:17  mcr
- * 	three parameter version of ip_select_ident appears first
- * 	in 2.4.2 (RH7.1) not 2.4.4.
- *
- * Revision 1.2  2002/03/08 21:35:22  rgb
- * Defined LINUX_KERNEL_HAS_SNPRINTF to shut up compiler warnings after
- * 2.4.9.  (Andreas Piesk).
- *
- * Revision 1.1  2002/01/29 02:11:42  mcr
- * 	removal of kversions.h - sources that needed it now use ipsec_param.h.
- * 	updating of IPv6 structures to match latest in6.h version.
- * 	removed dead code from freeswan.h that also duplicated kversions.h
- * 	code.
- *
- *
- */
