@@ -97,8 +97,8 @@ IPSEC_ALG_MODULE_INIT_STATIC( ipsec_cryptoapi_init )
 #define DIGESTNAME_SHA1		"sha1"
 
 MODULE_AUTHOR("Juanjo Ciarlante, Harpo MAxx, Luciano Ruete");
-static int debug_crypto=0;
-static int test_crypto=0;
+static int debug_crypto=1;
+static int test_crypto=1;
 static int excl_crypto=0;
 
 static int noauto = 0;
@@ -365,7 +365,14 @@ setup_cipher_list (struct ipsec_alg_capi_cipher* clist)
 					, cptr->parm[0]
 					, cptr->parm[1]);
 			continue;
-		}
+		} else 
+			if (debug_crypto>0)
+				printk(KERN_INFO "setup_cipher_list(): going to init ciphername=%s: noauto=%d parm[0]=%d parm[1]=%d\n",
+				, cptr->ciphername
+                                        , noauto
+                                        , cptr->parm[0]
+                                        , cptr->parm[1]);
+
 		/* 
 		 * 	use a local ci to avoid touching cptr->ci,
 		 * 	if register ipsec_alg success then bind cipher
