@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: pfkey_v2.c,v 1.97.2.16 2007-10-31 19:57:41 paul Exp $
+ * RCSID $Id: pfkey_v2.c,v 1.97.2.17 2008-06-26 20:48:31 paul Exp $
  */
 
 /*
@@ -86,6 +86,8 @@ extern int sysctl_ipsec_debug_verbose;
 #define SOCKOPS_WRAPPED(name) name
 #endif /* SOCKOPS_WRAPPED */
 
+extern struct proto_ops SOCKOPS_WRAPPED(pfkey_ops);
+
 #ifdef NET_26
 static rwlock_t pfkey_sock_lock = RW_LOCK_UNLOCKED;
 HLIST_HEAD(pfkey_sock_list);
@@ -718,7 +720,7 @@ pfkey_create(struct socket *sock, int protocol)
 
 	sk->sk_destruct = NULL;
 	sk->sk_reuse = 1;
-	sock->ops = &pfkey_ops;
+	sock->ops = &SOCKOPS_WRAPPED(pfkey_ops);
 
 	sk->sk_family = PF_KEY;
 /*	sk->num = protocol; */
@@ -1571,6 +1573,9 @@ void pfkey_proto_init(struct net_protocol *pro)
 
 /*
  * $Log: pfkey_v2.c,v $
+ * Revision 1.97.2.17  2008-06-26 20:48:31  paul
+ * SOCKOPS_WRAP fix for SMP builds on 2.4 and 2.6
+ *
  * Revision 1.97.2.16  2007-10-31 19:57:41  paul
  * type of sock.sk_stamp changed from timeval to ktime [dhr]
  *
