@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: connections.h,v 1.103.2.1 2005-11-17 01:44:12 mcr Exp $
+ * RCSID $Id: connections.h,v 1.103.2.3 2008-04-24 18:49:17 paul Exp $
  */
 
 /* There are two kinds of connections:
@@ -227,8 +227,6 @@ struct connection {
 				       next one to apply */
 
     struct gw_info *gw_info;
-    char                *alg_esp;    /* string the admin provided */
-    char                *alg_ike;    /* ditto. may be NULL */
     struct alg_info_esp *alg_info_esp;
     struct alg_info_ike *alg_info_ike;
 
