@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: demux.c,v 1.210.2.15 2007-09-05 03:02:19 paul Exp $
+ * RCSID $Id: demux.c,v 1.210.2.16 2008-06-16 01:03:04 paul Exp $
  */
 
 /* Ordering Constraints on Payloads
@@ -1439,6 +1439,8 @@ process_packet(struct msg_digest **mdp)
 	    struct isakmp_hdr *hdr = (struct isakmp_hdr *)md->packet_pbs.cur;
 	    if ((hdr->isa_version >> ISA_MAJ_SHIFT) != ISAKMP_MAJOR_VERSION)
 	    {
+		if ((hdr->isa_version >> ISA_MAJ_SHIFT) == IKEv2_MAJOR_VERSION)
+                        openswan_log("Received IKEv2 packet, but we only support IKEv1. Upgrade to Openswan 2.6.x and higher to support IKEv2. Sending notification in the hope that the other end will fallback to IKEv1.");
 		SEND_NOTIFICATION(INVALID_MAJOR_VERSION);
 		return;
 	    }
