@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: spdb_struct.c,v 1.13.2.16 2008-02-18 16:44:45 paul Exp $
+ * RCSID $Id: spdb_struct.c,v 1.13.2.17 2008-04-24 18:54:00 paul Exp $
  */
 
 #include <stdio.h>
@@ -131,15 +131,9 @@ out_sa(pb_stream *outs
 
 
     if(oakley_mode) {
-	const char *modestr;
-	const char *alginfo;
-
 	revised_sadb=oakley_alg_makedb(st->st_connection->alg_info_ike
 				       , sadb
 				       , aggressive_mode ? 1 : -1);
-	modestr = "ike";
-	alginfo = st->st_connection->alg_ike;
-
     } else {
 	revised_sadb=kernel_alg_makedb(st->st_connection->alg_info_esp, TRUE);
 
