@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: vendor.c,v 1.43.2.10 2007-10-28 07:00:23 paul Exp $
+ * RCSID $Id: vendor.c,v 1.43.2.11 2008-06-16 01:03:04 paul Exp $
  */
 
 #include <stdlib.h>
@@ -258,6 +258,8 @@ static struct vid_struct _vid_tab[] = {
 		"\xaf\xca\xd7\x13\x68\xa1\xf1\xc9\x6b\x86\x96\xfc\x77\x57\x01\x00",
 		16 },
 
+        { VID_MISC_IKEv2, VID_STRING|VID_KEEP, "IKEv2", "CAN-IKEv2", NULL, 0},
+
 	/**
 	 * Netscreen:
 	 * 4865617274426561745f4e6f74696679386b0100  (HeartBeat_Notify + 386b0100)
@@ -492,6 +494,11 @@ static void handle_known_vendorid (struct msg_digest *md UNUSED
 	    vid_usefull = 1;
             break;
 
+        case VID_MISC_IKEv2:
+            loglog(RC_LOG_SERIOUS,"IKEv2 Vendor ID payload received but not supported in this version");
+            vid_usefull = 1;
+            break;
+
 /* We only need these when dealing with XAUTH */
 #ifdef XAUTH
 	case VID_SSH_SENTINEL_1_4_1:
