@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: vendor.h,v 1.13.2.7 2007-11-07 12:40:51 ken Exp $
+ * RCSID $Id: vendor.h,v 1.13.2.8 2008-06-16 01:03:04 paul Exp $
  */
 
 #ifndef _VENDOR_H_
@@ -88,7 +88,8 @@ enum known_vendorid {
   VID_MISC_DPD               =202,
   VID_MISC_HEARTBEAT_NOTIFY  =203,
   VID_MISC_FRAGMENTATION     =204,
-  VID_INITIAL_CONTACT        =205
+  VID_INITIAL_CONTACT        =205,
+  VID_MISC_IKEv2             =206
 
 };
 
